@@ -43,9 +43,6 @@
 
 static gboolean _do_something (DmapConnection * connection);
 
-G_DEFINE_TYPE (DmapConnection, dmap_connection, G_TYPE_OBJECT);
-#define DMAP_CONNECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_CONNECTION, DmapConnectionPrivate))
-
 struct DmapConnectionPrivate
 {
 	char *name;
@@ -86,6 +83,13 @@ struct DmapConnectionPrivate
 	char *last_error_message;
 };
 
+G_DEFINE_TYPE_WITH_CODE (DmapConnection,
+                         dmap_connection,
+                         G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (DmapConnection));
+
+#define DMAP_CONNECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_CONNECTION, DmapConnectionPrivate))
+
 enum
 {
 	PROP_0,
@@ -329,8 +333,6 @@ dmap_connection_class_init (DmapConnectionClass * klass)
 	object_class->set_property = _set_property;
 	object_class->get_property = _get_property;
 
-	g_type_class_add_private (klass, sizeof (DmapConnectionPrivate));
-
 	g_object_class_install_property (object_class,
 					 PROP_DB,
 					 g_param_spec_object ("db",
@@ -649,7 +651,7 @@ _actual_http_response_handler (DmapResponseData * data)
 		soup_uri_to_string (soup_message_get_uri (data->message),
 				    FALSE);
 
-	g_debug ("Received response from %s: %d, %s\n",
+	g_debug ("Received response from %s: %d, %s",
 		 message_path,
 		 data->message->status_code, data->message->reason_phrase);
 
@@ -795,7 +797,7 @@ _actual_http_response_handler (DmapResponseData * data)
 					    data->connection);
 		}
 	} else {
-		g_debug ("Error getting %s: %d, %s\n",
+		g_debug ("Error getting %s: %d, %s",
 			 message_path,
 			 data->message->status_code,
 			 data->message->reason_phrase);
@@ -1096,7 +1098,7 @@ _handle_database_info (DmapConnection * connection,
 
 	n_databases = g_value_get_int (&(item->content));
 	if (n_databases != 1) {
-		g_debug ("Host seems to have more than 1 database, how strange\n");
+		g_debug ("Host seems to have more than 1 database, how strange");
 	}
 
 	listing_node = dmap_structure_find_node (structure, DMAP_CC_MLCL);
@@ -1377,7 +1379,7 @@ _handle_playlist_entries (DmapConnection * connection,
 					     GINT_TO_POINTER
 					     (playlist_item_id));
 		if (item_uri == NULL) {
-			g_debug ("Entry %d in playlist %s doesn't exist in the database\n", playlist_item_id, playlist->name);
+			g_debug ("Entry %d in playlist %s doesn't exist in the database", playlist_item_id, playlist->name);
 			continue;
 		}
 
