@@ -60,7 +60,10 @@ enum
 
 static guint _signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (DmapMdnsBrowser, dmap_mdns_browser, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_CODE (DmapMdnsBrowser,
+                         dmap_mdns_browser,
+                         G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (DmapMdnsBrowser));
 
 static void
 dmap_mdns_browser_init (DmapMdnsBrowser * browser)
@@ -490,8 +493,6 @@ dmap_mdns_browser_class_init (DmapMdnsBrowserClass * klass)
 	object_class->dispose  = _dispose;
 	object_class->finalize = _finalize;
 
-	g_type_class_add_private (klass, sizeof (DmapMdnsBrowserPrivate));
-
 	// Signal makeup
 	_signals[SERVICE_ADDED] =
 		g_signal_new ("service-added",
