@@ -116,7 +116,10 @@ struct share_bitwise_t
 static void dmap_share_init (DmapShare * share);
 static void dmap_share_class_init (DmapShareClass * klass);
 
-G_DEFINE_ABSTRACT_TYPE (DmapShare, dmap_share, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (DmapShare,
+                                  dmap_share,
+                                  G_TYPE_OBJECT,
+                                  G_ADD_PRIVATE (DmapShare))
 #define DMAP_SHARE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
 				   DMAP_TYPE_SHARE, DmapSharePrivate));
 
@@ -704,8 +707,6 @@ dmap_share_class_init (DmapShareClass * klass)
 							     G_TYPE_STRV,
 							     G_PARAM_READWRITE));
 
-	g_type_class_add_private (klass, sizeof (DmapSharePrivate));
-
 	_signals[ERROR] =
 		g_signal_new ("error",
 		               G_TYPE_FROM_CLASS (object_class),
@@ -917,7 +918,7 @@ dmap_share_message_set_from_dmap_structure (DmapShare * share,
 	resp = dmap_structure_serialize (structure, &length);
 
 	if (resp == NULL) {
-		g_warning ("Serialize gave us null?\n");
+		g_warning ("Serialize gave us null?");
 		return;
 	}
 
@@ -2119,7 +2120,7 @@ dmap_share_databases (DmapShare * share,
 		g_debug ("Assuming no artwork for requested group/album");
 		soup_message_set_status (message, SOUP_STATUS_NOT_FOUND);
 	} else {
-		g_warning ("Unhandled: %s\n", path);
+		g_warning ("Unhandled: %s", path);
 	}
 
 done:
